@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2005, 2007, 2010 Free Software
+   Copyright (C) 1999, 2001-2002, 2005, 2007, 2010-2012 Free Software
    Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
@@ -13,9 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "mail.h"
 
@@ -29,10 +27,10 @@ mail_inc (int argc MU_ARG_UNUSED, char **argv MU_ARG_UNUSED)
   if (!mu_mailbox_is_updated (mbox))
     {
       mu_mailbox_messages_count (mbox, &total);
-      fprintf (ofile, _("New mail has arrived.\n"));
+      mu_printf (_("New mail has arrived.\n"));
     }
   else
-    fprintf (ofile, _("No new mail for %s\n"), mail_whoami());
+    mu_printf (_("No new mail for %s\n"), mail_whoami ());
 
   return 0;
 }
