@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003, 
-   2004, 2005, 2007, 2008, 2009 Free Software Foundation, Inc.
+   Copyright (C) 1999-2005, 2007-2012 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,9 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifndef _POP3D_H
 #define _POP3D_H	1
@@ -23,8 +20,10 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include <mu_dbm.h>
-#include <mu_asprintf.h>
+#include <mailutils/types.h>
+#include <mailutils/stream.h>
+#include <mailutils/io.h>
+#include <mailutils/dbm.h>
 #include <mu_umaxtostr.h>
 #include <muaux.h>
 
@@ -35,8 +34,8 @@
    type automatically */
 #define APOP_PASSFILE_NAME "apop"
 
-#ifdef USE_DBM
-# define APOP_PASSFILE SYSCONFDIR "/" APOP_PASSFILE_NAME
+#ifdef ENABLE_DBM
+# define APOP_PASSFILE SYSCONFDIR "/" APOP_PASSFILE_NAME ".db"
 # define ENABLE_LOGIN_DELAY
 #else
 # define APOP_PASSFILE SYSCONFDIR "/" APOP_PASSFILE_NAME ".passwd"
@@ -65,16 +64,9 @@ extern int expire_on_exit;
 /* Size of the MD5 digest for APOP */
 #define APOP_DIGEST	70
 
-/* Longest legal POP command */
-#define POP_MAXCMDLEN	255
-
-/* Buffer size to use for output */
-#define BUFFERSIZE	1024
-
 #ifndef _GNU_SOURCE
 # define _GNU_SOURCE
 #endif
-#define _QNX_SOURCE
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -114,7 +106,7 @@ extern int expire_on_exit;
 #include <mailutils/locker.h>
 #include <mailutils/mailbox.h>
 #include <mailutils/message.h>
-#include <mailutils/mutil.h>
+#include <mailutils/util.h>
 #include <mailutils/mu_auth.h>
 #include <mailutils/nls.h>
 #include <mailutils/registrar.h>
@@ -123,6 +115,9 @@ extern int expire_on_exit;
 #include <mailutils/md5.h>
 #include <mailutils/acl.h>
 #include <mailutils/server.h>
+#include <mailutils/filter.h>
+#include <mailutils/stdstream.h>
+#include <mailutils/stream.h>
 
 /* For Berkley DB2 APOP password file */
 #ifdef HAVE_DB_H
@@ -137,12 +132,6 @@ extern int expire_on_exit;
 #include <shadow.h>
 #endif
 
-#ifndef MAXHOSTNAMELEN
-/* Maximum length of a hostname (is this defined somewhere else?).  */
-/* MAXHOSTNAMELEN is already defined on Solaris.  */
-# define MAXHOSTNAMELEN	64
-#endif
-
 #define POP3_ATTRIBUTE_DELE 0x0001
 #define POP3_ATTRIBUTE_RETR 0x0010
 
@@ -186,6 +175,7 @@ struct pop3d_command
   pop3d_command_handler_t handler;
 };
 
+extern mu_stream_t iostream;
 extern mu_pop_server_t pop3srv;
 extern mu_mailbox_t mbox;
 extern int state;
@@ -204,6 +194,23 @@ extern int undelete_on_startup;
 extern struct mu_auth_data *auth_data;
 extern unsigned int idle_timeout;
 extern int pop3d_transcript;
+extern size_t pop3d_output_bufsize;
+extern int pop3d_xlines;
+extern char *apop_database_name;
+extern int apop_database_safety;
+extern uid_t apop_database_owner;
+extern int apop_database_owner_set;
+
+/* Safety checks for group-rw database files, such as stat and bulletin
+   databases */
+   
+#define DEFAULT_GROUP_DB_SAFETY					\
+  (MU_FILE_SAFETY_WORLD_WRITABLE|				\
+   MU_FILE_SAFETY_WORLD_READABLE|				\
+   MU_FILE_SAFETY_LINKED_WRDIR|					\
+   MU_FILE_SAFETY_DIR_IWGRP|					\
+   MU_FILE_SAFETY_DIR_IWOTH)
+
 
 extern pop3d_command_handler_t pop3d_find_command (const char *name);
 
@@ -221,10 +228,12 @@ extern int pop3d_quit           (char *);
 extern int pop3d_retr           (char *);
 extern int pop3d_rset           (char *);
 
+void pop3d_send_payload (mu_stream_t stream, mu_stream_t linestr,
+			 size_t maxlines);
+
 extern void pop3d_bye           (void);
 extern int pop3d_abquit         (int);
 extern char *pop3d_apopuser     (const char *);
-extern int pop3d_lock           (void);
 extern void process_cleanup     (void);
 
 extern void pop3d_parse_command (char *cmd, char **pcmd, char **parg);
@@ -236,11 +245,9 @@ extern RETSIGTYPE pop3d_child_signal  (int);
 extern int pop3d_stls           (char *);
 extern void enable_stls (void);
 #endif /* WITH_TLS */
-extern int pop3d_touchlock      (void);
-extern int pop3d_unlock         (void);
 extern void pop3d_outf          (const char *fmt, ...) MU_PRINTFLIKE(1,2);
 
-extern void pop3d_setio         (FILE *in, FILE *out);
+extern void pop3d_setio         (int, int, int);
 extern char *pop3d_readline     (char *, size_t);
 extern void pop3d_flush_output  (void);
 
@@ -268,4 +275,6 @@ extern int set_bulletin_source (const char *source);
 extern int pop3d_begin_session (void);
 extern const char *pop3d_error_string (int code);
 
+extern int set_xscript_level (int xlev);
+
 #endif /* _POP3D_H */
