@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2005, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2005, 2007, 2010-2012 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -12,9 +12,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General
-   Public License along with this library; if not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA */
+   Public License along with this library.  If not, see
+   <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -160,7 +159,7 @@ odbc_query (mu_sql_connection_t conn, char *query)
       return MU_ERR_SQL;
     }
 
-  rc = SQLExecDirect (dp->stmt, query, SQL_NTS);   
+  rc = SQLExecDirect (dp->stmt, (SQLCHAR*) query, SQL_NTS);   
   if (rc != SQL_SUCCESS)
     {
       mu_odbc_diag (dp, SQL_HANDLE_STMT, dp->stmt, "SQLExecDirect");
@@ -189,7 +188,7 @@ static int
 odbc_release_result (mu_sql_connection_t conn)
 {
   struct mu_odbc_data *dp = conn->data;
-  mu_list_do (dp->result, odbc_free_char_data, NULL);
+  mu_list_foreach (dp->result, odbc_free_char_data, NULL);
   mu_list_destroy (&dp->result);
   mu_argcv_free (dp->fcount, dp->fnames);
   dp->fcount = 0;
@@ -252,9 +251,9 @@ odbc_get_column (mu_sql_connection_t conn,
       return MU_ERR_SQL;
     }
   
-  *pdata = strdup (buffer);
-  mu_list_append (dp->result, *pdata);
-  return 0;
+  if ((*pdata = strdup (buffer)) == NULL)
+    return ENOMEM;
+  return mu_list_append (dp->result, *pdata);
 }
 
 /* FIXME: untested */
@@ -305,7 +304,7 @@ odbc_get_field_number (mu_sql_connection_t conn, const char *fname,
 	  dp->fnames[i] = name;
 	  ret = SQLDescribeCol (dp->stmt,
 				i + 1,
-				name,
+				(SQLCHAR*) name,
 				namelen + 1,
 				&namelen,
 				NULL,
@@ -340,7 +339,7 @@ static const char *
 odbc_errstr (mu_sql_connection_t conn)
 {
   struct mu_odbc_data *dp = conn->data;   
-  char state[16];
+  SQLCHAR state[16];
   char nbuf[64];
   SQLINTEGER nerror;
   SQLSMALLINT msglen;
@@ -365,14 +364,14 @@ odbc_errstr (mu_sql_connection_t conn)
   
   snprintf (nbuf, sizeof nbuf, "%d", (int) nerror);
   length = strlen (dp->err.what) + 1
-             + strlen (state) + 1
+             + strlen ((char*) state) + 1
              + strlen (nbuf) + 1
-             + strlen (dp->err.msg) + 1;
+             + strlen ((char*) dp->err.msg) + 1;
   if (dp->err.text)
     free (dp->err.text);
   dp->err.text = malloc (length);
   if (!dp->err.text)
-    return dp->err.msg;
+    return (char*) dp->err.msg;
   
   snprintf (dp->err.text, length, "%s %s %s %s", dp->err.what, state, nbuf,
 	    dp->err.msg);
